# Dijit Tree Test

## Tree with hardcoded root node (not corresponding to any item in the store)

Clicking a folder node will open/close it (openOnclick==true), and clicking a leaf node will log a message to the console.

before:

## A rootless tree (no "continents" node) with context menus, and custom icons

before:

## Double click, expand on load, direct style setting, tooltip test tree

Double-Clicking a folder node will open/close it (openOnDblClick==true), and clicking or Double Clicking a leaf node will log a message to the console.

before:

## Tree w/horizontal scroll

For checking that selection and highlighting effect goes all the way to the right.

Expand North America and check highlighting for United States, plus shorter labels. Then collapse North America and make sure horizontal scrollbar disappears.

Also check whether the Tree's initial display is correct. Since the Tree persists, try refreshing the page when the tree is in an open state, and when it's in a closed state.